@@ -7,7 +7,7 @@ use warnings;
 use JSON;
 use Slack::RTM::Bot::Client;
 
-our $VERSION = "0.06";
+our $VERSION = "0.07";
 
 pipe(READH, WRITEH);
 select(WRITEH);$|=1;
@@ -28,17 +28,21 @@ sub start_RTM {
 
 	my $parent = $$;
 
+	unless(fork){
+		while (kill 0, $parent) {
+			print WRITEH "\n";
+			sleep 1;
+		}
+	}
 	my $pid = fork;
 	unless($pid) {
 		my $i = 0;
 		while (kill 0, $parent) {
-			print WRITEH "\n";
 			$client->read;
-			sleep 1;
 			(my $buffer = <READH>) =~ s/\n$//;
 			if($buffer){
 				$client->write(
-					%{JSON::from_json($buffer)}
+					%{JSON::from_json(Encode::decode_utf8($buffer))}
 				);
 			}
 			if($i++ % 30 == 0){
@@ -79,7 +83,6 @@ sub say {
 	my $args = {@_};
 
 	die "RTM not started." unless $self->{client};
-	my $client = $self->{client};
 
 	if(!defined $args->{text} || !defined $args->{channel}) {
 		die;
